==> s2i-annotations-2.6.0-sources.jar: io/dekorate/s2i/config/S2iBuildConfigFluentImpl.java <==
package io.dekorate.s2i.config;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.dekorate.kubernetes.config.ImageConfigurationFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.dekorate.kubernetes.config.Env;
import java.util.function.Predicate;
import java.lang.Integer;
import io.dekorate.kubernetes.config.EnvBuilder;
import io.dekorate.kubernetes.config.EnvFluentImpl;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public class S2iBuildConfigFluentImpl<A extends io.dekorate.s2i.config.S2iBuildConfigFluent<A>> extends io.dekorate.kubernetes.config.ImageConfigurationFluentImpl<A> implements io.dekorate.s2i.config.S2iBuildConfigFluent<A>{
  public S2iBuildConfigFluentImpl() {
  }
  public S2iBuildConfigFluentImpl(io.dekorate.s2i.config.S2iBuildConfig instance) {
    this.withProject(instance.getProject()); 
    this.withAttributes(instance.getAttributes()); 
    this.withRegistry(instance.getRegistry()); 
    this.withGroup(instance.getGroup()); 
    this.withName(instance.getName()); 
    this.withVersion(instance.getVersion()); 
    this.withImage(instance.getImage()); 
    this.withDockerFile(instance.getDockerFile()); 
    this.withAutoBuildEnabled(instance.getAutoBuildEnabled()); 
    this.withAutoPushEnabled(instance.getAutoPushEnabled()); 
    this.withEnabled(instance.getEnabled()); 
    this.withBuilderImage(instance.getBuilderImage()); 
    this.withBuildEnvVars(instance.getBuildEnvVars()); 
    this.withAutoDeployEnabled(instance.getAutoDeployEnabled()); 
  }
  private java.lang.Boolean enabled;
  private java.lang.String builderImage;
  private java.util.List<io.dekorate.kubernetes.config.EnvBuilder> buildEnvVars =  new java.util.ArrayList<io.dekorate.kubernetes.config.EnvBuilder>();
  private java.lang.Boolean autoDeployEnabled;
  public java.lang.Boolean getEnabled() {
    return this.enabled;
  }
  public A withEnabled(java.lang.Boolean enabled) {
    this.enabled=enabled; return (A) this;
  }
  public java.lang.Boolean hasEnabled() {
    return this.enabled != null;
  }
  public java.lang.String getBuilderImage() {
    return this.builderImage;
  }
  public A withBuilderImage(java.lang.String builderImage) {
    this.builderImage=builderImage; return (A) this;
  }
  public java.lang.Boolean hasBuilderImage() {
    return this.builderImage != null;
  }
  
  /**
   * Method is deprecated. use withBuilderImage instead.
   */
  @java.lang.Deprecated
  public A withNewBuilderImage(java.lang.String arg0) {
    return (A)withBuilderImage(new String(arg0));
  }
  public A withBuildEnvVars(io.dekorate.kubernetes.config.Env... buildEnvVars) {
    if (this.buildEnvVars != null) {this.buildEnvVars.clear();}
    if (buildEnvVars != null) {for (io.dekorate.kubernetes.config.Env item :buildEnvVars){ this.addToBuildEnvVars(item);}} return (A) this;
  }
  
  /**
   * This method has been deprecated, please use method buildBuildEnvVars instead.
   */
  @java.lang.Deprecated
  public io.dekorate.kubernetes.config.Env[] getBuildEnvVars() {
    int size = buildEnvVars != null ? buildEnvVars.size() : 0;
io.dekorate.kubernetes.config.Env[] result = new io.dekorate.kubernetes.config.Env[size];
if (size == 0) {
   return result;
}
int index = 0;
for (io.fabric8.kubernetes.api.builder.VisitableBuilder<? extends io.dekorate.kubernetes.config.Env,?> builder : buildEnvVars) {
    result[index++]=builder.build();
}
return result;

  }
  public io.dekorate.kubernetes.config.Env[] buildBuildEnvVars() {
    int size = buildEnvVars != null ? buildEnvVars.size() : 0;
io.dekorate.kubernetes.config.Env[] result = new io.dekorate.kubernetes.config.Env[size];
if (size == 0) {
   return result;
}
int index = 0;
for (io.fabric8.kubernetes.api.builder.VisitableBuilder<? extends io.dekorate.kubernetes.config.Env,?> builder : buildEnvVars) {
    result[index++]=builder.build();
}
return result;

  }
  public io.dekorate.kubernetes.config.Env buildBuildEnvVar(java.lang.Integer index) {
    return this.buildEnvVars.get(index).build();
  }
  public io.dekorate.kubernetes.config.Env buildFirstBuildEnvVar() {
    return this.buildEnvVars.get(0).build();
  }
  public io.dekorate.kubernetes.config.Env buildLastBuildEnvVar() {
    return this.buildEnvVars.get(buildEnvVars.size() - 1).build();
  }
  public io.dekorate.kubernetes.config.Env buildMatchingBuildEnvVar(java.util.function.Predicate<io.dekorate.kubernetes.config.EnvBuilder> predicate) {
    for (io.dekorate.kubernetes.config.EnvBuilder item: buildEnvVars) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingBuildEnvVar(java.util.function.Predicate<io.dekorate.kubernetes.config.EnvBuilder> predicate) {
    for (io.dekorate.kubernetes.config.EnvBuilder item: buildEnvVars) { if(predicate.test(item)){ return true;} } return false;
  }
  public A addToBuildEnvVars(java.lang.Integer index,io.dekorate.kubernetes.config.Env item) {
    if (this.buildEnvVars == null) {this.buildEnvVars = new java.util.ArrayList<io.dekorate.kubernetes.config.EnvBuilder>();}
    io.dekorate.kubernetes.config.EnvBuilder builder = new io.dekorate.kubernetes.config.EnvBuilder(item);_visitables.get("buildEnvVars").add(index >= 0 ? index : _visitables.get("buildEnvVars").size(), builder);this.buildEnvVars.add(index >= 0 ? index : buildEnvVars.size(), builder); return (A)this;
  }
  public A setToBuildEnvVars(java.lang.Integer index,io.dekorate.kubernetes.config.Env item) {
    if (this.buildEnvVars == null) {this.buildEnvVars = new java.util.ArrayList<io.dekorate.kubernetes.config.EnvBuilder>();}
    io.dekorate.kubernetes.config.EnvBuilder builder = new io.dekorate.kubernetes.config.EnvBuilder(item);
    if (index < 0 || index >= _visitables.get("buildEnvVars").size()) { _visitables.get("buildEnvVars").add(builder); } else { _visitables.get("buildEnvVars").set(index, builder);}
    if (index < 0 || index >= buildEnvVars.size()) { buildEnvVars.add(builder); } else { buildEnvVars.set(index, builder);}
     return (A)this;
  }
  public A addToBuildEnvVars(io.dekorate.kubernetes.config.Env... items) {
    if (this.buildEnvVars == null) {this.buildEnvVars = new java.util.ArrayList<io.dekorate.kubernetes.config.EnvBuilder>();}
    for (io.dekorate.kubernetes.config.Env item : items) {io.dekorate.kubernetes.config.EnvBuilder builder = new io.dekorate.kubernetes.config.EnvBuilder(item);_visitables.get("buildEnvVars").add(builder);this.buildEnvVars.add(builder);} return (A)this;
  }
  public A addAllToBuildEnvVars(java.util.Collection<io.dekorate.kubernetes.config.Env> items) {
    if (this.buildEnvVars == null) {this.buildEnvVars = new java.util.ArrayList<io.dekorate.kubernetes.config.EnvBuilder>();}
    for (io.dekorate.kubernetes.config.Env item : items) {io.dekorate.kubernetes.config.EnvBuilder builder = new io.dekorate.kubernetes.config.EnvBuilder(item);_visitables.get("buildEnvVars").add(builder);this.buildEnvVars.add(builder);} return (A)this;
  }
  public A removeFromBuildEnvVars(io.dekorate.kubernetes.config.Env... items) {
    for (io.dekorate.kubernetes.config.Env item : items) {io.dekorate.kubernetes.config.EnvBuilder builder = new io.dekorate.kubernetes.config.EnvBuilder(item);_visitables.get("buildEnvVars").remove(builder);if (this.buildEnvVars != null) {this.buildEnvVars.remove(builder);}} return (A)this;
  }
  public A removeAllFromBuildEnvVars(java.util.Collection<io.dekorate.kubernetes.config.Env> items) {
    for (io.dekorate.kubernetes.config.Env item : items) {io.dekorate.kubernetes.config.EnvBuilder builder = new io.dekorate.kubernetes.config.EnvBuilder(item);_visitables.get("buildEnvVars").remove(builder);if (this.buildEnvVars != null) {this.buildEnvVars.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromBuildEnvVars(java.util.function.Predicate<io.dekorate.kubernetes.config.EnvBuilder> predicate) {
    if (buildEnvVars == null) return (A) this;
    final Iterator<io.dekorate.kubernetes.config.EnvBuilder> each = buildEnvVars.iterator();
    final List visitables = _visitables.get("buildEnvVars");
    while (each.hasNext()) {
      io.dekorate.kubernetes.config.EnvBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  public java.lang.Boolean hasBuildEnvVars() {
    return buildEnvVars != null && !buildEnvVars.isEmpty();
  }
  public io.dekorate.s2i.config.S2iBuildConfigFluent.BuildEnvVarsNested<A> addNewBuildEnvVar() {
    return new io.dekorate.s2i.config.S2iBuildConfigFluentImpl.BuildEnvVarsNestedImpl();
  }
  public io.dekorate.s2i.config.S2iBuildConfigFluent.BuildEnvVarsNested<A> addNewBuildEnvVarLike(io.dekorate.kubernetes.config.Env item) {
    return new io.dekorate.s2i.config.S2iBuildConfigFluentImpl.BuildEnvVarsNestedImpl(-1, item);
  }
  public io.dekorate.s2i.config.S2iBuildConfigFluent.BuildEnvVarsNested<A> setNewBuildEnvVarLike(java.lang.Integer index,io.dekorate.kubernetes.config.Env item) {
    return new io.dekorate.s2i.config.S2iBuildConfigFluentImpl.BuildEnvVarsNestedImpl(index, item);
  }
  public io.dekorate.s2i.config.S2iBuildConfigFluent.BuildEnvVarsNested<A> editBuildEnvVar(java.lang.Integer index) {
    if (buildEnvVars.size() <= index) throw new RuntimeException("Can't edit buildEnvVars. Index exceeds size.");
    return setNewBuildEnvVarLike(index, buildBuildEnvVar(index));
  }
  public io.dekorate.s2i.config.S2iBuildConfigFluent.BuildEnvVarsNested<A> editFirstBuildEnvVar() {
    if (buildEnvVars.size() == 0) throw new RuntimeException("Can't edit first buildEnvVars. The list is empty.");
    return setNewBuildEnvVarLike(0, buildBuildEnvVar(0));
  }
  public io.dekorate.s2i.config.S2iBuildConfigFluent.BuildEnvVarsNested<A> editLastBuildEnvVar() {
    int index = buildEnvVars.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last buildEnvVars. The list is empty.");
    return setNewBuildEnvVarLike(index, buildBuildEnvVar(index));
  }
  public io.dekorate.s2i.config.S2iBuildConfigFluent.BuildEnvVarsNested<A> editMatchingBuildEnvVar(java.util.function.Predicate<io.dekorate.kubernetes.config.EnvBuilder> predicate) {
    int index = -1;
    for (int i=0;i<buildEnvVars.size();i++) { 
    if (predicate.test(buildEnvVars.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching buildEnvVars. No match found.");
    return setNewBuildEnvVarLike(index, buildBuildEnvVar(index));
  }
  public java.lang.Boolean getAutoDeployEnabled() {
    return this.autoDeployEnabled;
  }
  public A withAutoDeployEnabled(java.lang.Boolean autoDeployEnabled) {
    this.autoDeployEnabled=autoDeployEnabled; return (A) this;
  }
  public java.lang.Boolean hasAutoDeployEnabled() {
    return this.autoDeployEnabled != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    S2iBuildConfigFluentImpl that = (S2iBuildConfigFluentImpl) o;
    if (enabled != null ? !enabled.equals(that.enabled) :that.enabled != null) return false;
    if (builderImage != null ? !builderImage.equals(that.builderImage) :that.builderImage != null) return false;
    if (buildEnvVars != null ? !buildEnvVars.equals(that.buildEnvVars) :that.buildEnvVars != null) return false;
    if (autoDeployEnabled != null ? !autoDeployEnabled.equals(that.autoDeployEnabled) :that.autoDeployEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(enabled,  builderImage,  buildEnvVars,  autoDeployEnabled,  super.hashCode());
  }
  
 /**
  * Generated
  */
public class BuildEnvVarsNestedImpl<N> extends io.dekorate.kubernetes.config.EnvFluentImpl<io.dekorate.s2i.config.S2iBuildConfigFluent.BuildEnvVarsNested<N>> implements io.dekorate.s2i.config.S2iBuildConfigFluent.BuildEnvVarsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    BuildEnvVarsNestedImpl(java.lang.Integer index,io.dekorate.kubernetes.config.Env item) {
      this.index = index;
      this.builder = new io.dekorate.kubernetes.config.EnvBuilder(this, item);
    }
    BuildEnvVarsNestedImpl() {
      this.index = -1;
      this.builder = new io.dekorate.kubernetes.config.EnvBuilder(this);
    }
    io.dekorate.kubernetes.config.EnvBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) S2iBuildConfigFluentImpl.this.setToBuildEnvVars(index,builder.build());
    }
    public N endBuildEnvVar() {
      return and();
    }
    
  }
  
}

==> s2i-annotations-2.8.0-sources.jar: io/dekorate/s2i/config/S2iBuildConfigFluentImpl.java <==
package io.dekorate.s2i.config;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.dekorate.kubernetes.config.ImageConfigurationFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.dekorate.kubernetes.config.Env;
import java.util.function.Predicate;
import java.lang.Integer;
import io.dekorate.kubernetes.config.EnvBuilder;
import io.dekorate.kubernetes.config.EnvFluentImpl;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public class S2iBuildConfigFluentImpl<A extends io.dekorate.s2i.config.S2iBuildConfigFluent<A>> extends io.dekorate.kubernetes.config.ImageConfigurationFluentImpl<A> implements io.dekorate.s2i.config.S2iBuildConfigFluent<A>{
  public S2iBuildConfigFluentImpl() {
  }
  public S2iBuildConfigFluentImpl(io.dekorate.s2i.config.S2iBuildConfig instance) {
    this.withProject(instance.getProject()); 
    this.withAttributes(instance.getAttributes()); 
    this.withEnabled(instance.getEnabled()); 
    this.withRegistry(instance.getRegistry()); 
    this.withGroup(instance.getGroup()); 
    this.withName(instance.getName()); 
    this.withVersion(instance.getVersion()); 
    this.withImage(instance.getImage()); 
    this.withDockerFile(instance.getDockerFile()); 
    this.withAutoBuildEnabled(instance.getAutoBuildEnabled()); 
    this.withAutoPushEnabled(instance.getAutoPushEnabled()); 
    this.withAutoLoadEnabled(instance.isAutoLoadEnabled()); 
    this.withBuilderImage(instance.getBuilderImage()); 
    this.withBuildEnvVars(instance.getBuildEnvVars()); 
    this.withAutoDeployEnabled(instance.getAutoDeployEnabled()); 
  }
  private java.lang.String builderImage;
  private java.util.ArrayList<io.dekorate.kubernetes.config.EnvBuilder> buildEnvVars = new java.util.ArrayList<io.dekorate.kubernetes.config.EnvBuilder>();
  private java.lang.Boolean autoDeployEnabled;
  public java.lang.String getBuilderImage() {
    return this.builderImage;
  }
  public A withBuilderImage(java.lang.String builderImage) {
    this.builderImage=builderImage; return (A) this;
  }
  public java.lang.Boolean hasBuilderImage() {
    return this.builderImage != null;
  }
  
  /**
   * Method is deprecated. use withBuilderImage instead.
   */
  @java.lang.Deprecated
  public A withNewBuilderImage(java.lang.String arg0) {
    return (A)withBuilderImage(new String(arg0));
  }
  public A withBuildEnvVars(io.dekorate.kubernetes.config.Env... buildEnvVars) {
    if (this.buildEnvVars != null) {this.buildEnvVars.clear();}
    if (buildEnvVars != null) {for (io.dekorate.kubernetes.config.Env item :buildEnvVars){ this.addToBuildEnvVars(item);}} return (A) this;
  }
  
  /**
   * This method has been deprecated, please use method buildBuildEnvVars instead.
   */
  @java.lang.Deprecated
  public io.dekorate.kubernetes.config.Env[] getBuildEnvVars() {
    int size = buildEnvVars != null ? buildEnvVars.size() : 0;
io.dekorate.kubernetes.config.Env[] result = new io.dekorate.kubernetes.config.Env[size];
if (size == 0) {
   return result;
}
int index = 0;
for (io.fabric8.kubernetes.api.builder.VisitableBuilder<? extends io.dekorate.kubernetes.config.Env,?> builder : buildEnvVars) {
    result[index++]=builder.build();
}
return result;

  }
  public io.dekorate.kubernetes.config.Env[] buildBuildEnvVars() {
    int size = buildEnvVars != null ? buildEnvVars.size() : 0;
io.dekorate.kubernetes.config.Env[] result = new io.dekorate.kubernetes.config.Env[size];
if (size == 0) {
   return result;
}
int index = 0;
for (io.fabric8.kubernetes.api.builder.VisitableBuilder<? extends io.dekorate.kubernetes.config.Env,?> builder : buildEnvVars) {
    result[index++]=builder.build();
}
return result;

  }
  public io.dekorate.kubernetes.config.Env buildBuildEnvVar(java.lang.Integer index) {
    return this.buildEnvVars.get(index).build();
  }
  public io.dekorate.kubernetes.config.Env buildFirstBuildEnvVar() {
    return this.buildEnvVars.get(0).build();
  }
  public io.dekorate.kubernetes.config.Env buildLastBuildEnvVar() {
    return this.buildEnvVars.get(buildEnvVars.size() - 1).build();
  }
  public io.dekorate.kubernetes.config.Env buildMatchingBuildEnvVar(java.util.function.Predicate<io.dekorate.kubernetes.config.EnvBuilder> predicate) {
    for (io.dekorate.kubernetes.config.EnvBuilder item: buildEnvVars) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingBuildEnvVar(java.util.function.Predicate<io.dekorate.kubernetes.config.EnvBuilder> predicate) {
    for (io.dekorate.kubernetes.config.EnvBuilder item: buildEnvVars) { if(predicate.test(item)){ return true;} } return false;
  }
  public A addToBuildEnvVars(java.lang.Integer index,io.dekorate.kubernetes.config.Env item) {
    if (this.buildEnvVars == null) {this.buildEnvVars = new java.util.ArrayList<io.dekorate.kubernetes.config.EnvBuilder>();}
    io.dekorate.kubernetes.config.EnvBuilder builder = new io.dekorate.kubernetes.config.EnvBuilder(item);_visitables.get("buildEnvVars").add(index >= 0 ? index : _visitables.get("buildEnvVars").size(), builder);this.buildEnvVars.add(index >= 0 ? index : buildEnvVars.size(), builder); return (A)this;
  }
  public A setToBuildEnvVars(java.lang.Integer index,io.dekorate.kubernetes.config.Env item) {
    if (this.buildEnvVars == null) {this.buildEnvVars = new java.util.ArrayList<io.dekorate.kubernetes.config.EnvBuilder>();}
    io.dekorate.kubernetes.config.EnvBuilder builder = new io.dekorate.kubernetes.config.EnvBuilder(item);
    if (index < 0 || index >= _visitables.get("buildEnvVars").size()) { _visitables.get("buildEnvVars").add(builder); } else { _visitables.get("buildEnvVars").set(index, builder);}
    if (index < 0 || index >= buildEnvVars.size()) { buildEnvVars.add(builder); } else { buildEnvVars.set(index, builder);}
     return (A)this;
  }
  public A addToBuildEnvVars(io.dekorate.kubernetes.config.Env... items) {
    if (this.buildEnvVars == null) {this.buildEnvVars = new java.util.ArrayList<io.dekorate.kubernetes.config.EnvBuilder>();}
    for (io.dekorate.kubernetes.config.Env item : items) {io.dekorate.kubernetes.config.EnvBuilder builder = new io.dekorate.kubernetes.config.EnvBuilder(item);_visitables.get("buildEnvVars").add(builder);this.buildEnvVars.add(builder);} return (A)this;
  }
  public A addAllToBuildEnvVars(java.util.Collection<io.dekorate.kubernetes.config.Env> items) {
    if (this.buildEnvVars == null) {this.buildEnvVars = new java.util.ArrayList<io.dekorate.kubernetes.config.EnvBuilder>();}
    for (io.dekorate.kubernetes.config.Env item : items) {io.dekorate.kubernetes.config.EnvBuilder builder = new io.dekorate.kubernetes.config.EnvBuilder(item);_visitables.get("buildEnvVars").add(builder);this.buildEnvVars.add(builder);} return (A)this;
  }
  public A removeFromBuildEnvVars(io.dekorate.kubernetes.config.Env... items) {
    for (io.dekorate.kubernetes.config.Env item : items) {io.dekorate.kubernetes.config.EnvBuilder builder = new io.dekorate.kubernetes.config.EnvBuilder(item);_visitables.get("buildEnvVars").remove(builder);if (this.buildEnvVars != null) {this.buildEnvVars.remove(builder);}} return (A)this;
  }
  public A removeAllFromBuildEnvVars(java.util.Collection<io.dekorate.kubernetes.config.Env> items) {
    for (io.dekorate.kubernetes.config.Env item : items) {io.dekorate.kubernetes.config.EnvBuilder builder = new io.dekorate.kubernetes.config.EnvBuilder(item);_visitables.get("buildEnvVars").remove(builder);if (this.buildEnvVars != null) {this.buildEnvVars.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromBuildEnvVars(java.util.function.Predicate<io.dekorate.kubernetes.config.EnvBuilder> predicate) {
    if (buildEnvVars == null) return (A) this;
    final Iterator<io.dekorate.kubernetes.config.EnvBuilder> each = buildEnvVars.iterator();
    final List visitables = _visitables.get("buildEnvVars");
    while (each.hasNext()) {
      io.dekorate.kubernetes.config.EnvBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  public java.lang.Boolean hasBuildEnvVars() {
    return buildEnvVars != null && !buildEnvVars.isEmpty();
  }
  public io.dekorate.s2i.config.S2iBuildConfigFluent.BuildEnvVarsNested<A> addNewBuildEnvVar() {
    return new io.dekorate.s2i.config.S2iBuildConfigFluentImpl.BuildEnvVarsNestedImpl();
  }
  public io.dekorate.s2i.config.S2iBuildConfigFluent.BuildEnvVarsNested<A> addNewBuildEnvVarLike(io.dekorate.kubernetes.config.Env item) {
    return new io.dekorate.s2i.config.S2iBuildConfigFluentImpl.BuildEnvVarsNestedImpl(-1, item);
  }
  public io.dekorate.s2i.config.S2iBuildConfigFluent.BuildEnvVarsNested<A> setNewBuildEnvVarLike(java.lang.Integer index,io.dekorate.kubernetes.config.Env item) {
    return new io.dekorate.s2i.config.S2iBuildConfigFluentImpl.BuildEnvVarsNestedImpl(index, item);
  }
  public io.dekorate.s2i.config.S2iBuildConfigFluent.BuildEnvVarsNested<A> editBuildEnvVar(java.lang.Integer index) {
    if (buildEnvVars.size() <= index) throw new RuntimeException("Can't edit buildEnvVars. Index exceeds size.");
    return setNewBuildEnvVarLike(index, buildBuildEnvVar(index));
  }
  public io.dekorate.s2i.config.S2iBuildConfigFluent.BuildEnvVarsNested<A> editFirstBuildEnvVar() {
    if (buildEnvVars.size() == 0) throw new RuntimeException("Can't edit first buildEnvVars. The list is empty.");
    return setNewBuildEnvVarLike(0, buildBuildEnvVar(0));
  }
  public io.dekorate.s2i.config.S2iBuildConfigFluent.BuildEnvVarsNested<A> editLastBuildEnvVar() {
    int index = buildEnvVars.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last buildEnvVars. The list is empty.");
    return setNewBuildEnvVarLike(index, buildBuildEnvVar(index));
  }
  public io.dekorate.s2i.config.S2iBuildConfigFluent.BuildEnvVarsNested<A> editMatchingBuildEnvVar(java.util.function.Predicate<io.dekorate.kubernetes.config.EnvBuilder> predicate) {
    int index = -1;
    for (int i=0;i<buildEnvVars.size();i++) { 
    if (predicate.test(buildEnvVars.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching buildEnvVars. No match found.");
    return setNewBuildEnvVarLike(index, buildBuildEnvVar(index));
  }
  public java.lang.Boolean getAutoDeployEnabled() {
    return this.autoDeployEnabled;
  }
  public A withAutoDeployEnabled(java.lang.Boolean autoDeployEnabled) {
    this.autoDeployEnabled=autoDeployEnabled; return (A) this;
  }
  public java.lang.Boolean hasAutoDeployEnabled() {
    return this.autoDeployEnabled != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    S2iBuildConfigFluentImpl that = (S2iBuildConfigFluentImpl) o;
    if (builderImage != null ? !builderImage.equals(that.builderImage) :that.builderImage != null) return false;
    if (buildEnvVars != null ? !buildEnvVars.equals(that.buildEnvVars) :that.buildEnvVars != null) return false;
    if (autoDeployEnabled != null ? !autoDeployEnabled.equals(that.autoDeployEnabled) :that.autoDeployEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(builderImage,  buildEnvVars,  autoDeployEnabled,  super.hashCode());
  }
  
 /**
  * Generated
  */
public class BuildEnvVarsNestedImpl<N> extends io.dekorate.kubernetes.config.EnvFluentImpl<io.dekorate.s2i.config.S2iBuildConfigFluent.BuildEnvVarsNested<N>> implements io.dekorate.s2i.config.S2iBuildConfigFluent.BuildEnvVarsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    BuildEnvVarsNestedImpl(java.lang.Integer index,io.dekorate.kubernetes.config.Env item) {
      this.index = index;
      this.builder = new io.dekorate.kubernetes.config.EnvBuilder(this, item);
    }
    BuildEnvVarsNestedImpl() {
      this.index = -1;
      this.builder = new io.dekorate.kubernetes.config.EnvBuilder(this);
    }
    io.dekorate.kubernetes.config.EnvBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) S2iBuildConfigFluentImpl.this.setToBuildEnvVars(index,builder.build());
    }
    public N endBuildEnvVar() {
      return and();
    }
    
  }
  
}
